==> openshift-serverless-logic-1.27.0-src.zip: openshift-serverless-logic-1.27.0.GA-src/org.kie.kogito-kogito-apps-1.32.0.Final/ui-packages/packages/process-details/src/envelope/ProcessDetailsEnvelope.tsx <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import * as React from 'react';
import * as ReactDOM from 'react-dom';
import { EnvelopeBus } from '@kogito-tooling/envelope-bus/dist/api';
import { ProcessDetailsChannelApi, ProcessDetailsEnvelopeApi } from '../api';
import { Envelope, EnvelopeDivConfig } from '@kogito-tooling/envelope';
import { ProcessDetailsEnvelopeContext } from './ProcessDetailsEnvelopeContext';
import {
  ProcessDetailsEnvelopeView,
  ProcessDetailsEnvelopeViewApi
} from './ProcessDetailsEnvelopeView';
import { ProcessDetailsEnvelopeApiImpl } from './ProcessDetailsEnvelopeApiImpl';

/**
 * Function that starts an Envelope application.
 * @param args.config: This passes envelope div config
 * @param args.container: The HTML element in which the Process details View will render
 * @param args.bus: The implementation of a `bus` that knows how to send messages to the Channel.
 *
 */
export function init(args: {
  config: EnvelopeDivConfig;
  container: HTMLElement;
  bus: EnvelopeBus;
}) {
  /**
   * Creates a new generic Envelope, typed with the right interfaces.
   */
  const envelope = new Envelope<
    ProcessDetailsEnvelopeApi,
    ProcessDetailsChannelApi,
    ProcessDetailsEnvelopeViewApi,
    ProcessDetailsEnvelopeContext
  >(args.bus, args.config);

  const envelopeViewDelegate = async () => {
    const ref = React.createRef<ProcessDetailsEnvelopeViewApi>();
    return new Promise<() => ProcessDetailsEnvelopeViewApi>(res => {
      ReactDOM.render(
        <ProcessDetailsEnvelopeView
          ref={ref}
          channelApi={envelope.channelApi}
        />,
        args.container,
        () => res(() => ref.current!)
      );
    });
  };

  const context: ProcessDetailsEnvelopeContext = {};
  return envelope.start(envelopeViewDelegate, context, {
    create: apiFactoryArgs => new ProcessDetailsEnvelopeApiImpl(apiFactoryArgs)
  });
}

==> openshift-serverless-logic-1.30.0-src.zip: openshift-serverless-logic-1.30.0.GA-src/org.kie.kogito-kogito-apps-1.40.0.Final/ui-packages/packages/process-details/src/envelope/ProcessDetailsEnvelope.tsx <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import * as React from 'react';
import * as ReactDOM from 'react-dom';
import { EnvelopeBus } from '@kogito-tooling/envelope-bus/dist/api';
import { ProcessDetailsChannelApi, ProcessDetailsEnvelopeApi } from '../api';
import { Envelope, EnvelopeDivConfig } from '@kogito-tooling/envelope';
import { ProcessDetailsEnvelopeContext } from './ProcessDetailsEnvelopeContext';
import {
  ProcessDetailsEnvelopeView,
  ProcessDetailsEnvelopeViewApi
} from './ProcessDetailsEnvelopeView';
import { ProcessDetailsEnvelopeApiImpl } from './ProcessDetailsEnvelopeApiImpl';

/**
 * Function that starts an Envelope application.
 * @param args.config: This passes envelope div config
 * @param args.container: The HTML element in which the Process details View will render
 * @param args.bus: The implementation of a `bus` that knows how to send messages to the Channel.
 *
 */
export function init(args: {
  config: EnvelopeDivConfig;
  container: HTMLElement;
  bus: EnvelopeBus;
}) {
  /**
   * Creates a new generic Envelope, typed with the right interfaces.
   */
  const envelope = new Envelope<
    ProcessDetailsEnvelopeApi,
    ProcessDetailsChannelApi,
    ProcessDetailsEnvelopeViewApi,
    ProcessDetailsEnvelopeContext
  >(args.bus, args.config);

  const envelopeViewDelegate = async () => {
    const ref = React.createRef<ProcessDetailsEnvelopeViewApi>();
    return new Promise<() => ProcessDetailsEnvelopeViewApi>((res) => {
      ReactDOM.render(
        <ProcessDetailsEnvelopeView
          ref={ref}
          channelApi={envelope.channelApi}
        />,
        args.container,
        () => res(() => ref.current!)
      );
    });
  };

  const context: ProcessDetailsEnvelopeContext = {};
  return envelope.start(envelopeViewDelegate, context, {
    create: (apiFactoryArgs) =>
      new ProcessDetailsEnvelopeApiImpl(apiFactoryArgs)
  });
}
